@@ -32,10 +32,11 @@
 
 from typing import List
 
-from dimsdk import ID
-from dimsdk import ReliableMessage
-from dimsdk import Content
-from dimsdk import BaseCommandProcessor
+from dimp import ID
+from dimp import ReliableMessage
+from dimp import Content
+
+from dimsdk.cpu import BaseCommandProcessor
 
 from ...utils import Logging
 from ...common import LoginCommand
