@@ -45,8 +45,9 @@ from startrek import Docker, DockerStatus
 from startrek import Arrival
 
 from ..utils import hex_encode, random_bytes
-from ..utils import Log, Logging
+from ..utils import Log
 from ..common import SessionDBI
+from ..database import ReliableMessageTable
 from ..conn import BaseSession
 from ..conn import WSArrival, MarsStreamArrival, MTPStreamArrival
 
@@ -58,7 +59,7 @@ def generate_session_key() -> str:
     return hex_encode(random_bytes(32))
 
 
-class ServerSession(BaseSession, Logging):
+class ServerSession(BaseSession):
     """
         Session for Connection
         ~~~~~~~~~~~~~~~~~~~~~~
@@ -99,12 +100,13 @@ class ServerSession(BaseSession, Logging):
         if super().set_active(active=active, when=when):
             session_change_active(session=self, active=active)
             load_cached_messages(session=self)
+            return True
 
     @property  # Override
     def running(self) -> bool:
         if super().running:
             gate = self.gate
-            conn = gate.get_connection(remote=self.remote_address, local=None)
+            conn = gate.get_channel(remote=self.remote_address, local=None)
             return not (conn is None or conn.closed)
 
     #
@@ -201,10 +203,20 @@ def load_cached_messages(session: ServerSession) -> int:
         return -1
     messenger = session.messenger
     db = messenger.database
-    messages = db.reliable_messages(receiver=identifier)
-    cnt = len(messages)
-    Log.info(msg='[DB] %d cached message(s) loaded for: %s' % (cnt, identifier))
-    for msg in messages:
-        data = messenger.serialize_message(msg=msg)
-        session.queue_message_package(msg=msg, data=data, priority=1)
-    return cnt
+    total = 0
+    start = 0
+    limit = 1024
+    remaining = 1
+    while remaining > 0:
+        messages, remaining = db.reliable_messages(receiver=identifier, start=start, limit=limit)
+        start += limit
+        cnt = len(messages)
+        total += cnt
+        Log.info(msg='[DB] %d cached message(s) loaded for: %s' % (cnt, identifier))
+        for msg in messages:
+            data = messenger.serialize_message(msg=msg)
+            session.queue_message_package(msg=msg, data=data, priority=1)
+        if total > ReliableMessageTable.CACHE_LIMIT:
+            Log.warning(msg='[DB] too many cached messages for: %s' % identifier)
+            break
+    return total
